@@ -1,38 +1,41 @@
 #! /usr/bin/perl -w
 #
-# reads an article on STDIN, mails any copies if requied,
+# reads an article on STDIN, mails any copies if required,
 # signs the article and posts it.
 #
 #
-# Copyright (c) 2002-2018 Urs Janssen <urs@tin.org>,
+# Copyright (c) 2002-2020 Urs Janssen <urs@tin.org>,
 #                         Marc Brockschmidt <marc@marcbrockschmidt.de>
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
 # are met:
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
+#
+# 1. Redistributions of source code must retain the above copyright notice,
+#    this list of conditions and the following disclaimer.
+#
 # 2. Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-# 3. The name of the author may not be used to endorse or promote
-#    products derived from this software without specific prior written
-#    permission.
 #
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR
-# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-# DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
-# INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
-# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
-# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
-# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# 3. Neither the name of the copyright holder nor the names of its
+#    contributors may be used to endorse or promote products derived from
+#    this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 #
 #
-# TODO: - add debug mode which doesn't delete tmp-files and is verbose
+# TODO: - extend debug mode to not delete tmp-files and be more verbose
 #       - add pid to pgptmpf to allow multiple simultaneous instances
 #       - check for /etc/nntpserver (and /etc/news/server)
 #       - add $PGPOPTS, $PGPPATH and $GNUPGHOME support
@@ -50,7 +53,7 @@ use strict;
 use warnings;
 
 # version Number
-my $version = "1.1.49";
+my $version = "1.1.51";
 
 my %config;
 
@@ -75,7 +78,7 @@ $config{'sig_path'}		= glob('~/.signature');	# path to signature
 $config{'add_signature'}= 'yes';# Add $config{'sig_path'} to posting if there is no sig
 $config{'sig_max_lines'}= 4;	# max number of signatures lines
 
-$config{'sendmail'}		= '| /usr/sbin/sendmail -i -t'; # set to '' to disable mail-actions
+$config{'sendmail'}		= '/usr/sbin/sendmail -i -t'; # set to '' to disable mail-actions
 
 $config{'pgptmpf'}		= 'pgptmp';	# temporary file for PGP.
 
@@ -131,6 +134,11 @@ if (defined($TINEWSRC)) {
 	close($TINEWSRC);
 }
 
+# as of tinews 1.1.51 we use 3 args open() to pipe to sendmail
+# thus we remove any leading '|' to avoid syntax errors;
+# for redirections use cat etc.pp., eg. 'cat > /tmp/foo'
+$config{'sendmail'} =~ s/^\s*\|\s*//io;
+
 # digest-algo is case sensitive and should be all uppercase
 $config{'digest-algo'} = uc($config{'digest-algo'});
 
@@ -482,7 +490,7 @@ if (! $config{'savedir'}) {
 
 # mail article
 if (($To || $Cc || $Bcc) && $config{'sendmail'}) {
-	open(my $MAIL, $config{'sendmail'}) || die("$!");
+	open(my $MAIL, '|-', $config{'sendmail'}) || die("$!");
 	unshift @$MessageR, "$To" if ($To);
 	unshift @$MessageR, "$Cc" if ($Cc);
 	unshift @$MessageR, "$Bcc" if ($Bcc);
@@ -556,7 +564,7 @@ sub getdate {
 # are defined, the sub will try to ask the user (only if
 # $config{'Interactive'} is != 0).
 sub AuthonNNTP {
-	my $Server = Net::NNTP->new($config{'NNTPServer'}, Reader => 1, Debug => 0, Port => $config{'NNTPPort'})
+	my $Server = Net::NNTP->new($config{'NNTPServer'}, Reader => 1, Debug => $config{'debug'}, Port => $config{'NNTPPort'})
 		or die("$0: Can't connect to ".$config{'NNTPServer'}.":".$config{'NNTPPort'}."!\n");
 	my $ServerMsg = "";
 	my $ServerCod = $Server->code();
@@ -909,6 +917,8 @@ sub usage {
 	print "  -v         show version\n";
 	print "  -w string  set Followup-To:-header to string\n";
 	print "  -x string  set Path:-header to string\n";
+	print "  -D         enable debugging\n";
+	print "  -F string  set References:-header to string\n";
 	print "  -H         show help\n";
 	print "  -I         do not add Injection-Date: header\n";
 	print "  -L         do not add Cancel-Lock: / Cancel-Key: headers\n";
@@ -934,6 +944,10 @@ B<tinews.pl> [B<OPTIONS>] E<lt> I<input>
 B<tinews.pl> reads an article on STDIN, signs it via L<pgp(1)> or
 L<gpg(1)> and posts it to a news server.
 
+The article shall not contain any raw 8-bit data or it needs to
+already have the relevant MIME-headers as B<tinews.pl> will not
+add any MIME-headers nor encode its input.
+
 If the article contains To:, Cc: or Bcc: headers and mail-actions are
 configured it will automatically add a "Posted-And-Mailed: yes" header
 to the article and send out the mail-copies.
@@ -944,7 +958,7 @@ Cancel-Lock: (and Cancel-Key: if required) header.
 The input should have unix line endings (<LF>, '\n').
 
 =head1 OPTIONS
-X<tinews, commandline options>
+X<tinews, command-line options>
 
 =over 4
 
@@ -1091,7 +1105,9 @@ These options are accepted for compatibility reasons but ignored.
 =item -B<D> | -B<N> | --B<debug>
 X<-D> X<-N> X<--debug>
 
-These options are accepted but do not have any functionality yet.
+Enable warnings about raw 8-bit data and set L<Net::NNTP(3pm)> in debug
+mode, enable warnings about raw 8-bit data, warn about disabled options
+due to lacking perl-modules or executables and unreadable files.
 
 =back
 
@@ -1164,7 +1180,7 @@ The '-B<r>' command-line option overrides B<$REPLYTO>.
 X<$ORGANIZATION> X<ORGANIZATION>
 
 Set the article header field Organization: to the contents of the variable
-if there isn't already a Organization: header in the article. The '-B<o>'
+if there isn't already an Organization: header in the article. The '-B<o>'
 command-line option overrides B<$ORGANIZATION>.
 
 =item B<$DISTRIBUTION>
@@ -1241,8 +1257,8 @@ B<tinews.pl> requires the following standard modules to be installed:
 L<Getopt::Long(3pm)>, L<Net::NNTP(3pm)>, <Time::Local(3pm)> and
 L<Term::Readline(3pm)>.
 
-If the Cancel-Lock feature is enabled the following additional modules
-must be installed: L<MIME::Base64(3pm)>, L<Digest::SHA(3pm)> or
+If the Cancel-Lock feature (RFC 8315) is enabled the following additional
+modules must be installed: L<MIME::Base64(3pm)>, L<Digest::SHA(3pm)> or
 L<Digest::SHA1(3pm)> and L<Digest::HMAC_SHA1(3pm)>. sha256 and sha512 as
 algorithms for B<canlock-algorithm> are only available with L<Digest::SHA(3pm)>.
 
@@ -1253,6 +1269,9 @@ L<gpg2(1)> users may need to set B<$GPG_TTY>, i.e.
 
 before using B<tinews.pl>. See L<https://www.gnupg.org/> for details.
 
+B<tinews.pl> does not do any MIME encoding, its input should be already
+properly encoded and have all relevant headers set.
+
 =head1 AUTHOR
 
 Urs Janssen E<lt>urs@tin.orgE<gt>,
